# -*- coding: utf-8 -*-
"""Tracing Span Entities.

@author Hao Song (songhao@vmware.com)
"""
